package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import java.util.Enumeration;

public class SignerInfo extends ASN1Encodable {
   private DERInteger version;
   private IssuerAndSerialNumber issuerAndSerialNumber;
   private AlgorithmIdentifier digAlgorithm;
   private ASN1Set authenticatedAttributes;
   private AlgorithmIdentifier digEncryptionAlgorithm;
   private ASN1OctetString encryptedDigest;
   private ASN1Set unauthenticatedAttributes;

   public static SignerInfo getInstance(Object o) {
      if (o instanceof SignerInfo) {
         return (SignerInfo)o;
      } else if (o instanceof ASN1Sequence) {
         return new SignerInfo((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + o.getClass().getName());
      }
   }

   public SignerInfo(DERInteger version, IssuerAndSerialNumber issuerAndSerialNumber, AlgorithmIdentifier digAlgorithm, ASN1Set authenticatedAttributes, AlgorithmIdentifier digEncryptionAlgorithm, ASN1OctetString encryptedDigest, ASN1Set unauthenticatedAttributes) {
      this.version = version;
      this.issuerAndSerialNumber = issuerAndSerialNumber;
      this.digAlgorithm = digAlgorithm;
      this.authenticatedAttributes = authenticatedAttributes;
      this.digEncryptionAlgorithm = digEncryptionAlgorithm;
      this.encryptedDigest = encryptedDigest;
      this.unauthenticatedAttributes = unauthenticatedAttributes;
   }

   public SignerInfo(ASN1Sequence seq) {
      Enumeration seq1;
      Enumeration var10000 = seq1 = seq.getObjects();
      this.version = (DERInteger)seq1.nextElement();
      this.issuerAndSerialNumber = IssuerAndSerialNumber.getInstance(seq1.nextElement());
      this.digAlgorithm = AlgorithmIdentifier.getInstance(seq1.nextElement());
      Object var2;
      if ((var2 = var10000.nextElement()) instanceof ASN1TaggedObject) {
         this.authenticatedAttributes = ASN1Set.getInstance((ASN1TaggedObject)var2, false);
         this.digEncryptionAlgorithm = AlgorithmIdentifier.getInstance(seq1.nextElement());
      } else {
         this.authenticatedAttributes = null;
         this.digEncryptionAlgorithm = AlgorithmIdentifier.getInstance(var2);
      }

      this.encryptedDigest = ASN1OctetString.getInstance(seq1.nextElement());
      if (seq1.hasMoreElements()) {
         this.unauthenticatedAttributes = ASN1Set.getInstance((ASN1TaggedObject)seq1.nextElement(), false);
      } else {
         this.unauthenticatedAttributes = null;
      }

   }

   public DERInteger getVersion() {
      return this.version;
   }

   public IssuerAndSerialNumber getIssuerAndSerialNumber() {
      return this.issuerAndSerialNumber;
   }

   public ASN1Set getAuthenticatedAttributes() {
      return this.authenticatedAttributes;
   }

   public AlgorithmIdentifier getDigestAlgorithm() {
      return this.digAlgorithm;
   }

   public ASN1OctetString getEncryptedDigest() {
      return this.encryptedDigest;
   }

   public AlgorithmIdentifier getDigestEncryptionAlgorithm() {
      return this.digEncryptionAlgorithm;
   }

   public ASN1Set getUnauthenticatedAttributes() {
      return this.unauthenticatedAttributes;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var1.add(this.issuerAndSerialNumber);
      var10001.add(this.digAlgorithm);
      ASN1Set var2;
      if ((var2 = this.authenticatedAttributes) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(false, 0, var2);
         var1.add(var3);
      }

      var1.add(this.digEncryptionAlgorithm);
      var1.add(this.encryptedDigest);
      ASN1Set var4;
      if ((var4 = this.unauthenticatedAttributes) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(false, 1, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
